@@ -53,15 +53,17 @@ from .modules.cabinet.count_file import count_file
 from .modules.cabinet.split_txt import split_txt_file
 from .modules.cabinet.license import apply_license
 from .modules.cabinet.stack_imgs import stack_imgs
+from .modules.cabinet.webcam import webcam_test
+from .modules.cabinet.markdown_tool import download_images_from_md
 
 from .modules.dltool.cal_anchors import KmeansYolo
 
 from alfred.utils.log import logger as logging
 
-__VERSION__ = '👍    2.8.2'
+__VERSION__ = '👍    2.8.5'
 __AUTHOR__ = '😀    Lucas Jin'
 __CONTACT__ = '😍    wechat: jintianiloveu'
-__DATE__ = '👉    2020.11.01, since 2019.11.11'
+__DATE__ = '👉    2021.05.01, since 2019.11.11'
 __LOC__ = '👉    Shenzhen, China'
 __git__ = '👍    http://github.com/jinfagang/alfred'
 
@@ -183,12 +185,25 @@ def arg_parse():
     apply_license_parser.add_argument(
         '--except', '-e', help='except extensions: xml,cc,h')
 
+    webcam_parser = cabinet_sub_parser.add_parser(
+        'webcam', help='Test your webcam.')
+    webcam_parser.set_defaults(which='cab-webcam')
+    webcam_parser.add_argument(
+        '--file', '-f', help='Also can set file.')
+
+    downmd_parser = cabinet_sub_parser.add_parser(
+        'downmd', help='Download all images to local from a markdown file.')
+    downmd_parser.set_defaults(which='cab-downmd')
+    downmd_parser.add_argument(
+        '--file', '-f', help='Also can set file.')
+
     # =============== dl tools part =============
     dltool_parser = main_sub_parser.add_parser(
         'dltool', help='dltool related commands.')
     dltool_sub_parser = dltool_parser.add_subparsers()
 
-    anchor_parser = dltool_sub_parser.add_parser('anchor', help='calculate anchors for you.')
+    anchor_parser = dltool_sub_parser.add_parser(
+        'anchor', help='calculate anchors for you.')
     anchor_parser.set_defaults(which='dltool-anchor')
     anchor_parser.add_argument(
         '--annotation_dir', '-a', help='VOC xml dir or yolo lables dir.')
@@ -197,7 +212,6 @@ def arg_parse():
     anchor_parser.add_argument(
         '--format', '-f', default='voc', help='Your annotation format: voc | yolo.')
 
-
     # =============== data part ================
     data_parser = main_sub_parser.add_parser(
         'data', help='data related commands.')
@@ -447,6 +461,12 @@ def main(args=None):
                     url = args_dict['url']
                     d = args_dict['dir']
                     apply_license(owner, project_name, year, url, d)
+                elif action == 'webcam':
+                    f = args_dict['file']
+                    webcam_test(f)
+                elif action == 'downmd':
+                    f = args_dict['file']
+                    download_images_from_md(f)
             elif module == 'dltool':
                 if action == 'anchor':
                     ann_dir = args_dict['annotation_dir']
